pub struct Timestamps {
pub creation: i64,
pub modification: i64,
}Expand description
Timestamps.
Fields
creation: i64The time of creation in seconds relative to 1904-01-01T00:00:00+00:00.
modification: i64The time of modification in seconds relative to 1904-01-01T00:00:00+00:00.